@@ -1,7 +1,7 @@
 use v6;
 use fatal;
 
-unit class Getopt::Long:ver<0.1.4>;
+unit class Getopt::Long:ver<0.1.5>;
 
 my sub null-converter(Str:D $value --> Str) {
 	return $value;
@@ -283,7 +283,7 @@ method new-from-sub(Sub $main) {
 	return self.new(:%options);
 }
 
-method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$bundling = True, :$compat-singles = False, :$write-args) {
+method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$compat-builtin = False, :$bundling = !$compat-builtin, :$compat-singles = $compat-builtin, :$compat-negation = $compat-builtin, :$write-args) {
 	my @list;
 	while @args {
 		my $head = @args.shift;
@@ -334,7 +334,12 @@ method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$
 			}
 		}
 
-		if $bundling && $head ~~ / ^ '-' $<values>=[\w <[\w-]>*] $ / -> $/ {
+		if $compat-singles && $head ~~ / ^ '-' $<name>=<alnum> '=' $<value>=[.*] / -> $/ {
+			my $option = get-option($<name>);
+			die Exception.new("$<name> doesn't take one argument") if $option.arity.max != 1;
+			take-value($option, ~$<value>);
+		}
+		elsif $bundling && $head ~~ / ^ '-' $<values>=[\w .* ] $ / -> $/ {
 			my @values = $<values>.Str.comb;
 			for @values.keys -> $index {
 				my $value = @values[$index];
@@ -360,10 +365,15 @@ method get-options(@args is copy, :%hash, :named-anywhere(:$permute) = False, :$
 			take-value($option, ~$<value>);
 			take-args($option);
 		}
-		elsif $compat-singles && $head ~~ / ^ '-' $<name>=<alnum> '=' $<value>=[.*] / -> $/ {
-			my $option = get-option($<name>);
-			die Exception.new("$<name> doesn't take one argument") if $option.arity.max != 1;
-			take-value($option, ~$<value>);
+		elsif $compat-negation && $head ~~ / ^ '-' ** 1..2 '/' $<name>=[\w <[\w-]>*] ['=' $<value>=[.*]]?  $ / {
+			if $<value> {
+				my $option = get-option($<name>);
+				die Exception.new("$<name> doesn't take an argument") if $option.arity.max != 1;
+				take-value($option, ~$<value> but False);
+			}
+			else {
+				take-args(get-option('no-' ~ $<name>));
+			}
 		}
 		else {
 			if $permute {
@@ -427,7 +437,7 @@ my sub call-main(CallFrame $callframe, $retval) {
 our sub ARGS-TO-CAPTURE(Sub $func, @args) is export(:DEFAULT, :MAIN) {
 	my %options = %*SUB-MAIN-OPTS // {};
 	return Getopt::Long.new-from-sub($func).get-options(@args, |%options, :write-args(@args));
-	CATCH { note .message; &*EXIT(2) };
+	CATCH { when Exceptional { note .message; &*EXIT(2) } };
 }
 
 our &MAIN_HELPER is export(:DEFAULT, :MAIN) = $*PERL.compiler.version after 2018.06
@@ -947,7 +957,16 @@ is equivalent to
 =end item
 
 =begin item
-bundling (default: enabled)
+compat-builtin (default: disabled)
+
+Enable all compatibility options that make argument parsing more like
+the builtin argument parsing. Currently that means disabling C<bundling>
+and enabling C<compat-singles> and C<compat-negation>.
+
+=end item
+
+=begin item
+bundling (default: C<!$compat-builtin>)
 
 Enabling this option will allow single-character options to be
 bundled. To distinguish bundles from long option names, long options
@@ -966,7 +985,7 @@ arguments and option settings are:
 =end item
 
 =begin item
-compat-singles (default: disabled)
+compat-singles (default: C<$compat-builtin>)
 
 Enabling this will allow single letter arguments with an C<=> between
 the letter and its argument. E.g. C<-j=2> instead of C<-j2>. This is for
@@ -974,6 +993,16 @@ compatibility with raku's built-in argument parsing.
 
 =end item
 
+=begin item
+compat-negation (default: C<$compat-builtin>)
+
+Enabling this will allow one to one to use C<--/foo> as an alias for
+C<--no-foo>, for compatibility with raku's built-in argument parsing.
+Note that this still requires the presence of a C<--no-foo> handler,
+typically by using the C<!> modifier.
+
+=end item
+
 =head1 Return values and Errors
 
 C<get-options> returns a capture to indicate success.
